; ===============================================================;
; ----- Generate perturbations based on GLDAS NOAH-MOSAIC EOFs for
; ----- SMC from GEFS sfc analysis files - unperturbed SMC ----- ;
; ===============================================================;
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/contributed.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/esmf/ESMF_regridding.ncl"

begin

  REGRID = True
  PLOT   = True

  if REGRID then
    print("Regrid option is on.")
  else
    print("Regrid option is off.")
  end if
  if PLOT then
    print("Plot option is on.")
  else
    print("Plot option is off.")
  end if
  
; --- generate random data --- ;
  print("defining data array")
  data = random_normal(0,5,(/180,360/))
  data!0 = "lat"
  data!1 = "lon"
  lat = fspan(-89.5,89.5,180)
  lon = fspan(0,359,360)
  lat!0 = "lat"
  lat@units = "degrees_north"
  lon!0 = "lon"
  lon@units = "degrees_east"
  lat&lat = lat
  lon&lon = lon
  data&lat = lat
  data&lon = lon
  printVarSummary(data)

  if REGRID then
    print("Regridding!")
  ; --- new lat and lon arrays to regrid to --- ;  
    print("defining new lat and lon arrays")
    newlat = fspan(-89.75,89.75,360)
    newlon = fspan(0,359.5,720)
    nlat = dimsizes(newlat)
    nlon = dimsizes(newlon)

  ; --- regridding options and file names --- ;
    srcGridName = "src_1deg.nc"
    dstGridName = "dst_0.5deg.nc"
    wgtFile_pfx = "1x1deg_to_0.5x0.5deg"
    outFile_pfx = "regrid_out"
    
    print("defining options for regridding")
    Opt                  = True
    Opt@SrcFileName      = srcGridName    ; name of output source file
    Opt@ForceOverwrite   = True    
    Opt@SrcInputFileName = "Test_regrid"    ; optional, but good idea
    Opt@SrcTitle         = "1deg Grid"   
    Opt@DstTitle      = "0.5deg Grid"
    Opt@DstGridLon    = newlon
    Opt@DstGridLat    = newlat
    Opt@DstFileName   = dstGridName
    Opt@WgtFileName   = wgtFile_pfx + "neareststod.nc"
    Opt@InterpMethod  = "neareststod"
    print("Regridding using method = neareststod")
    dataout           = ESMF_regrid(data,Opt)
    printVarSummary(dataout)
  end if

  if PLOT then
    print("Plotting!")
    print("open workstation")
    wks = gsn_open_wks("png","test_png")
    res = True
    res@cnFillOn = True
    res@cnLinesOn = False
    res@cnFillMode = "RasterFill"
    res@cnLevelSelectionMode = "ExplicitLevels"
    res@cnLevels = (/-2., -1., -0.5, 0.5, 1, 2/)
    print("plotting data")
    plot = gsn_csm_contour_map_ce(wks,data,res)
  end if

  
end